# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-20 23:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0026_auto_20170818_1123'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(blank=True, help_text=b"Will be used, with package info, to generate additional items' slugs.", max_length=20, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-09-24 19:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0031_auto_20170821_1251'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='printpublication',
            options={'ordering': ['priority', 'is_active', 'slug'], 'verbose_name': 'publishing destination'},
        ),
        migrations.AlterModelOptions(
            name='printsection',
            options={'ordering': ['priority', 'is_active', 'slug'], 'verbose_name': 'placement type'},
        ),
        migrations.AlterField(
            model_name='printsection',
            name='priority',
            field=models.PositiveSmallIntegerField(default=0, help_text='In the list of all active print publications, how high should this entry show up?'),
        ),
    ]



# Imports from Django.  # NOQA
from django.conf import settings


# Imports from other dependencies.
from rest_framework.pagination import LimitOffsetPagination


class ItemViewPagination(LimitOffsetPagination):
    default_limit = getattr(settings, 'BUDGET_API_MAX_ITEMS', 500)
    max_limit = getattr(settings, 'BUDGET_API_MAX_ITEMS', 500)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-20 23:30
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0027_auto_20170820_1820'),
    ]

    operations = [
        migrations.AlterField(
            model_name='package',
            name='slug_key',
            field=models.CharField(help_text=b'Miniature package descriptor. Will be used to generate the slug.', max_length=25, null=True),
        ),
    ]



# Imports from Django.  # NOQA
from django.core.exceptions import ValidationError


# Imports from other dependencies.
from editorial_staff.models import Hub


def hub_exists(value):
    """Validate that a hub exists"""
    try:
        Hub.objects.get(slug=value)
    except Hub.DoesNotExist:
        raise ValidationError('Hub "%s" does not exist.' % value)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-24 02:47
from __future__ import unicode_literals

import django.contrib.postgres.fields.ranges
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0009_auto_20160623_2139'),
    ]

    operations = [
        migrations.AddField(
            model_name='package',
            name='print_run_date',
            field=django.contrib.postgres.fields.ranges.DateRangeField(null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10 on 2017-08-18 00:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0024_auto_20160824_0945'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='item',
            options={'ordering': ['slug_key']},
        ),
        migrations.AddField(
            model_name='package',
            name='slug_key',
            field=models.CharField(help_text=b'Miniature package descriptor. Will be used to generate the slug.', max_length=20, null=True),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(help_text=b"Will be used, with package info, to generate additional items' slugs.", max_length=20),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-28 17:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0018_auto_20160628_1037'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='length',
            field=models.PositiveIntegerField(blank=True, help_text=b'How long is this article?', null=True, verbose_name=b'Length (in words)'),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug',
            field=models.CharField(db_index=True, editable=False, max_length=100, unique=True),
        ),
        migrations.AlterField(
            model_name='item',
            name='slug_key',
            field=models.CharField(help_text=b'Will be used, with package info, to generate the slug', max_length=20),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-29 00:06
from __future__ import unicode_literals

import django.contrib.postgres.fields.ranges
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0037_auto_20171028_1702'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentplacement',
            name='run_date',
            field=django.contrib.postgres.fields.ranges.DateRangeField(),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-21 16:28
from __future__ import unicode_literals

import datetime
from django.db import migrations


def print_date_to_daterange(apps, schema_editor):
    """Convert the legacy pring_run_date fields to new range fields"""
    Package = apps.get_model("budget", "Package")
    for package in Package.objects.filter(print_run_date_old__isnull=False):
        lower_bound = package.print_run_date_old
        upper_bound = lower_bound + datetime.timedelta(days=1)
        package.print_run_date = (lower_bound, upper_bound)
        package.save()


def default_dateranges(apps, schema_editor):
    """Walk back the date range migration to the field defaults"""
    Package = apps.get_model("budget", "Package")
    for package in Package.objects.all():
        package.print_run_date = None
        package.save()


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0010_package_print_run_date'),
    ]

    operations = [
        migrations.RunPython(
            print_date_to_daterange,
            default_dateranges
        )
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-29 00:02
from __future__ import unicode_literals
from datetime import date


from django.db import migrations


from psycopg2.extras import DateRange


DEFAULT_RUN_DATE = DateRange(
    date(2017, 1, 1),
    date(2017, 1, 4),
    '[)'
)


def provide_default_date_range(apps, schema_editor):
    ContentPlacement = apps.get_model('budget', 'ContentPlacement')

    for placement in ContentPlacement.objects.filter(run_date__isnull=True):
        placement.run_date = DEFAULT_RUN_DATE
        placement.save()


class Migration(migrations.Migration):

    dependencies = [
        ('budget', '0036_auto_20171028_1655'),
    ]

    operations = [
        migrations.RunPython(provide_default_date_range),
    ]
